==> cscec5b-wzxt-api-3.0.0-20210630.014028-254-sources.jar: com/ejianc/business/wzxt/vo/OrderDetailVO.java <==
package com.ejianc.business.wzxt.vo;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 订单明细表
 * 
 * @author generator
 * 
 */
public class OrderDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.String detailIndex; // 序号
    private java.lang.Long parentId; // parent_id
    private Long tid;
    private Boolean leafFlag; // 是否末级
    private java.lang.Long orderId; // 订单主键ID
    private java.lang.Long planId; // 计划主键ID
    private java.lang.Long planDetailId; // 计划明细主键ID
    private java.lang.String planName; // 使用计划名称
    private java.lang.String planBillCode; // 计划编码
    private java.lang.String planEmployeeName; // 计划编制人
    private java.lang.String construction; // 施工部位
    private java.lang.Long materialId; // 物资主键
    private java.lang.String materialName; // 物资名称
    private java.lang.Long materialTypeId; // 物资类别
    private java.lang.String materialTypeName; // 物资类别名称
    private java.lang.String materialCode; // 物料编码
    private java.lang.String unit; // 单位
    private java.lang.String spec; // 规格型号
    private java.math.BigDecimal planNumsSum; // 计划数量
    private java.math.BigDecimal receiveNumsSum; // 接收数量
    private java.math.BigDecimal surplusNumsSum; // 计划剩余数量
    private java.math.BigDecimal orderNumsSum; // 订单数量
    private java.math.BigDecimal deliverNumsSum; // 发货数量
    private java.math.BigDecimal unDeliverNumsSum; // 未发货数量
    private java.math.BigDecimal checkNumsSum; // 验收数量
    private java.lang.String materialManufacturer; // 生产厂家
    private java.lang.String memo; // 备注
    private java.lang.String sourceName; // 来源

    private java.lang.String materialSourceId; // 物资来源id
    private java.math.BigDecimal stockAmountSum; // 库存数量
    private String smartStatus;//智能称重标识
    private String originSmartStatus;//智能称重标识
    private Integer historyFlag;//是否历史数据(1是,0否)
    private java.lang.String historySystem; // 来源系统
    private java.lang.String historyId; // 来源主键
    private java.lang.String def1;
    private java.lang.String def2;
    private java.lang.String def3;
    private java.lang.String def4;
    private java.lang.String def5;

    private String childId;
    // 订单表主键
    private String mainId;

    private java.math.BigDecimal backNumsSum; // 退回数量

    public BigDecimal getBackNumsSum() {
        return backNumsSum;
    }

    public void setBackNumsSum(BigDecimal backNumsSum) {
        this.backNumsSum = backNumsSum;
    }

    public String getChildId() {
        return childId;
    }

    public void setChildId(String childId) {
        this.childId = childId;
    }

    public String getMainId() {
        return mainId;
    }

    public void setMainId(String mainId) {
        this.mainId = mainId;
    }

    public String getDef1() {
        return def1;
    }

    public void setDef1(String def1) {
        this.def1 = def1;
    }

    public String getDef2() {
        return def2;
    }

    public void setDef2(String def2) {
        this.def2 = def2;
    }

    public String getDef3() {
        return def3;
    }

    public void setDef3(String def3) {
        this.def3 = def3;
    }

    public String getDef4() {
        return def4;
    }

    public void setDef4(String def4) {
        this.def4 = def4;
    }

    public String getDef5() {
        return def5;
    }

    public void setDef5(String def5) {
        this.def5 = def5;
    }

    public String getMaterialSourceId() {
        return materialSourceId;
    }

    public void setMaterialSourceId(String materialSourceId) {
        this.materialSourceId = materialSourceId;
    }

    public BigDecimal getStockAmountSum() {
        return stockAmountSum;
    }

    public void setStockAmountSum(BigDecimal stockAmountSum) {
        this.stockAmountSum = stockAmountSum;
    }

    public String getSmartStatus() {
        return smartStatus;
    }

    public void setSmartStatus(String smartStatus) {
        this.smartStatus = smartStatus;
    }

    public String getOriginSmartStatus() {
        return originSmartStatus;
    }

    public void setOriginSmartStatus(String originSmartStatus) {
        this.originSmartStatus = originSmartStatus;
    }

    public Integer getHistoryFlag() {
        return historyFlag;
    }

    public void setHistoryFlag(Integer historyFlag) {
        this.historyFlag = historyFlag;
    }

    public String getHistorySystem() {
        return historySystem;
    }

    public void setHistorySystem(String historySystem) {
        this.historySystem = historySystem;
    }

    public String getHistoryId() {
        return historyId;
    }

    public void setHistoryId(String historyId) {
        this.historyId = historyId;
    }

    public String getSourceName() {
        return sourceName;
    }

    public void setSourceName(String sourceName) {
        this.sourceName = sourceName;
    }

    private List<OrderDetailVO> children; //子集数据

    public List<OrderDetailVO> getChildren() {
        return children;
    }

    public void setChildren(List<OrderDetailVO> children) {
        this.children = children;
    }

    public Long getTid() {
        return tid;
    }

    public void setTid(Long tid) {
        this.tid = tid;
    }

    public BigDecimal getUnDeliverNumsSum() {
        return unDeliverNumsSum;
    }

    public void setUnDeliverNumsSum(BigDecimal unDeliverNumsSum) {
        this.unDeliverNumsSum = unDeliverNumsSum;
    }

    /**
     * 序号
     */
    public java.lang.String getDetailIndex() {
        return detailIndex;
    }

    /**
     * 序号
     */
    public void setDetailIndex(java.lang.String detailIndex) {
        this.detailIndex = detailIndex;
    }
    /**
     * parent_id
     */
    public java.lang.Long getParentId() {
        return parentId;
    }

    /**
     * parent_id
     */
    public void setParentId(java.lang.Long parentId) {
        this.parentId = parentId;
    }
    /**
     * 是否末级
     */
    public Boolean getLeafFlag() {
        return leafFlag;
    }

    public void setLeafFlag(Boolean leafFlag) {
        this.leafFlag = leafFlag;
    }

    /**
     * 订单主键ID
     */
    public java.lang.Long getOrderId() {
        return orderId;
    }

    /**
     * 订单主键ID
     */
    public void setOrderId(java.lang.Long orderId) {
        this.orderId = orderId;
    }
    /**
     * 计划主键ID
     */
    public java.lang.Long getPlanId() {
        return planId;
    }

    /**
     * 计划主键ID
     */
    public void setPlanId(java.lang.Long planId) {
        this.planId = planId;
    }
    /**
     * 计划明细主键ID
     */
    public java.lang.Long getPlanDetailId() {
        return planDetailId;
    }

    /**
     * 计划明细主键ID
     */
    public void setPlanDetailId(java.lang.Long planDetailId) {
        this.planDetailId = planDetailId;
    }
    /**
     * 使用计划名称
     */
    public java.lang.String getPlanName() {
        return planName;
    }

    /**
     * 使用计划名称
     */
    public void setPlanName(java.lang.String planName) {
        this.planName = planName;
    }
    /**
     * 计划编码
     */
    public java.lang.String getPlanBillCode() {
        return planBillCode;
    }

    /**
     * 计划编码
     */
    public void setPlanBillCode(java.lang.String planBillCode) {
        this.planBillCode = planBillCode;
    }
    /**
     * 计划编制人
     */
    public java.lang.String getPlanEmployeeName() {
        return planEmployeeName;
    }

    /**
     * 计划编制人
     */
    public void setPlanEmployeeName(java.lang.String planEmployeeName) {
        this.planEmployeeName = planEmployeeName;
    }
    /**
     * 施工部位
     */
    public java.lang.String getConstruction() {
        return construction;
    }

    /**
     * 施工部位
     */
    public void setConstruction(java.lang.String construction) {
        this.construction = construction;
    }
    /**
     * 物资主键
     */
    public java.lang.Long getMaterialId() {
        return materialId;
    }

    /**
     * 物资主键
     */
    public void setMaterialId(java.lang.Long materialId) {
        this.materialId = materialId;
    }
    /**
     * 物资名称
     */
    public java.lang.String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(java.lang.String materialName) {
        this.materialName = materialName;
    }
    /**
     * 物资类别
     */
    public java.lang.Long getMaterialTypeId() {
        return materialTypeId;
    }

    /**
     * 物资类别
     */
    public void setMaterialTypeId(java.lang.Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    /**
     * 物资类别名称
     */
    public java.lang.String getMaterialTypeName() {
        return materialTypeName;
    }

    /**
     * 物资类别名称
     */
    public void setMaterialTypeName(java.lang.String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    /**
     * 物料编码
     */
    public java.lang.String getMaterialCode() {
        return materialCode;
    }

    /**
     * 物料编码
     */
    public void setMaterialCode(java.lang.String materialCode) {
        this.materialCode = materialCode;
    }
    /**
     * 单位
     */
    public java.lang.String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(java.lang.String unit) {
        this.unit = unit;
    }
    /**
     * 规格型号
     */
    public java.lang.String getSpec() {
        return spec;
    }

    /**
     * 规格型号
     */
    public void setSpec(java.lang.String spec) {
        this.spec = spec;
    }
    /**
     * 计划数量
     */
    public java.math.BigDecimal getPlanNumsSum() {
        return planNumsSum;
    }

    /**
     * 计划数量
     */
    public void setPlanNumsSum(java.math.BigDecimal planNumsSum) {
        this.planNumsSum = planNumsSum;
    }
    /**
     * 接收数量
     */
    public java.math.BigDecimal getReceiveNumsSum() {
        return receiveNumsSum;
    }

    /**
     * 接收数量
     */
    public void setReceiveNumsSum(java.math.BigDecimal receiveNumsSum) {
        this.receiveNumsSum = receiveNumsSum;
    }
    /**
     * 计划剩余数量
     */
    public java.math.BigDecimal getSurplusNumsSum() {
        return surplusNumsSum;
    }

    /**
     * 计划剩余数量
     */
    public void setSurplusNumsSum(java.math.BigDecimal surplusNumsSum) {
        this.surplusNumsSum = surplusNumsSum;
    }
    /**
     * 订单数量
     */
    public java.math.BigDecimal getOrderNumsSum() {
        return orderNumsSum;
    }

    /**
     * 订单数量
     */
    public void setOrderNumsSum(java.math.BigDecimal orderNumsSum) {
        this.orderNumsSum = orderNumsSum;
    }
    /**
     * 发货数量
     */
    public java.math.BigDecimal getDeliverNumsSum() {
        return deliverNumsSum;
    }

    /**
     * 发货数量
     */
    public void setDeliverNumsSum(java.math.BigDecimal deliverNumsSum) {
        this.deliverNumsSum = deliverNumsSum;
    }
    /**
     * 验收数量
     */
    public java.math.BigDecimal getCheckNumsSum() {
        return checkNumsSum;
    }

    /**
     * 验收数量
     */
    public void setCheckNumsSum(java.math.BigDecimal checkNumsSum) {
        this.checkNumsSum = checkNumsSum;
    }
    /**
     * 生产厂家
     */
    public java.lang.String getMaterialManufacturer() {
        return materialManufacturer;
    }

    /**
     * 生产厂家
     */
    public void setMaterialManufacturer(java.lang.String materialManufacturer) {
        this.materialManufacturer = materialManufacturer;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    
}

==> cscec5b-wzxt-api-3.0.0-20210812.084545-317-sources.jar: com/ejianc/business/wzxt/vo/OrderDetailVO.java <==
package com.ejianc.business.wzxt.vo;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 订单明细表
 * 
 * @author generator
 * 
 */
public class OrderDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.String detailIndex; // 序号
    private java.lang.Long parentId; // parent_id
    private Long tid;
    private Boolean leafFlag; // 是否末级
    private java.lang.Long orderId; // 订单主键ID
    private java.lang.Long planId; // 计划主键ID
    private java.lang.Long planDetailId; // 计划明细主键ID
    private java.lang.String planName; // 使用计划名称
    private java.lang.String planBillCode; // 计划编码
    private java.lang.String planEmployeeName; // 计划编制人
    private java.lang.String construction; // 施工部位
    private java.lang.Long materialId; // 物资主键
    private java.lang.String materialName; // 物资名称
    private java.lang.Long materialTypeId; // 物资类别
    private java.lang.String materialTypeName; // 物资类别名称
    private java.lang.String materialCode; // 物料编码
    private java.lang.String unit; // 单位
    private java.lang.String spec; // 规格型号
    private java.math.BigDecimal planNumsSum; // 计划数量
    private java.math.BigDecimal receiveNumsSum; // 接收数量
    private java.math.BigDecimal surplusNumsSum; // 计划剩余数量
    private java.math.BigDecimal orderNumsSum; // 订单数量
    private java.math.BigDecimal deliverNumsSum; // 发货数量
    private java.math.BigDecimal unDeliverNumsSum; // 未发货数量
    private java.math.BigDecimal checkNumsSum; // 验收数量
    private java.lang.String materialManufacturer; // 生产厂家
    private java.lang.String memo; // 备注
    private java.lang.String sourceName; // 来源

    private java.lang.String materialSourceId; // 物资来源id
    private java.math.BigDecimal stockAmountSum; // 库存数量
    private String smartStatus;//智能称重标识
    private String originSmartStatus;//智能称重标识
    private Integer historyFlag;//是否历史数据(1是,0否)
    private java.lang.String historySystem; // 来源系统
    private java.lang.String historyId; // 来源主键
    private java.lang.String def1;
    private java.lang.String def2;
    private java.lang.String def3;
    private java.lang.String def4;
    private java.lang.String def5;

    private String childId;
    // 订单表主键
    private String mainId;

    private java.math.BigDecimal backNumsSum; // 退回数量

    private java.math.BigDecimal price; // 单价
    private java.math.BigDecimal taxPrice; // 含税单价
    private java.math.BigDecimal taxRate; // 税率
    private java.lang.String width; // 宽度
    private java.lang.String height; // 高度
    private java.lang.String length; // 长度
    private java.lang.String surface; // 表面处理
    private java.lang.String color; // 颜色
    private java.lang.String colorNumber; // 色号
    private java.lang.String textureMaterial; // 材质状态
    private java.lang.String wallThickness; // 壁厚要求
    private java.lang.String buildingNumber; // 栋号

    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }

    public BigDecimal getTaxPrice() {
        return taxPrice;
    }

    public void setTaxPrice(BigDecimal taxPrice) {
        this.taxPrice = taxPrice;
    }

    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }

    public String getWidth() {
        return width;
    }

    public void setWidth(String width) {
        this.width = width;
    }

    public String getHeight() {
        return height;
    }

    public void setHeight(String height) {
        this.height = height;
    }

    public String getLength() {
        return length;
    }

    public void setLength(String length) {
        this.length = length;
    }

    public String getSurface() {
        return surface;
    }

    public void setSurface(String surface) {
        this.surface = surface;
    }

    public String getColor() {
        return color;
    }

    public void setColor(String color) {
        this.color = color;
    }

    public String getColorNumber() {
        return colorNumber;
    }

    public void setColorNumber(String colorNumber) {
        this.colorNumber = colorNumber;
    }

    public String getTextureMaterial() {
        return textureMaterial;
    }

    public void setTextureMaterial(String textureMaterial) {
        this.textureMaterial = textureMaterial;
    }

    public String getWallThickness() {
        return wallThickness;
    }

    public void setWallThickness(String wallThickness) {
        this.wallThickness = wallThickness;
    }

    public String getBuildingNumber() {
        return buildingNumber;
    }

    public void setBuildingNumber(String buildingNumber) {
        this.buildingNumber = buildingNumber;
    }

    public BigDecimal getBackNumsSum() {
        return backNumsSum;
    }

    public void setBackNumsSum(BigDecimal backNumsSum) {
        this.backNumsSum = backNumsSum;
    }

    public String getChildId() {
        return childId;
    }

    public void setChildId(String childId) {
        this.childId = childId;
    }

    public String getMainId() {
        return mainId;
    }

    public void setMainId(String mainId) {
        this.mainId = mainId;
    }

    public String getDef1() {
        return def1;
    }

    public void setDef1(String def1) {
        this.def1 = def1;
    }

    public String getDef2() {
        return def2;
    }

    public void setDef2(String def2) {
        this.def2 = def2;
    }

    public String getDef3() {
        return def3;
    }

    public void setDef3(String def3) {
        this.def3 = def3;
    }

    public String getDef4() {
        return def4;
    }

    public void setDef4(String def4) {
        this.def4 = def4;
    }

    public String getDef5() {
        return def5;
    }

    public void setDef5(String def5) {
        this.def5 = def5;
    }

    public String getMaterialSourceId() {
        return materialSourceId;
    }

    public void setMaterialSourceId(String materialSourceId) {
        this.materialSourceId = materialSourceId;
    }

    public BigDecimal getStockAmountSum() {
        return stockAmountSum;
    }

    public void setStockAmountSum(BigDecimal stockAmountSum) {
        this.stockAmountSum = stockAmountSum;
    }

    public String getSmartStatus() {
        return smartStatus;
    }

    public void setSmartStatus(String smartStatus) {
        this.smartStatus = smartStatus;
    }

    public String getOriginSmartStatus() {
        return originSmartStatus;
    }

    public void setOriginSmartStatus(String originSmartStatus) {
        this.originSmartStatus = originSmartStatus;
    }

    public Integer getHistoryFlag() {
        return historyFlag;
    }

    public void setHistoryFlag(Integer historyFlag) {
        this.historyFlag = historyFlag;
    }

    public String getHistorySystem() {
        return historySystem;
    }

    public void setHistorySystem(String historySystem) {
        this.historySystem = historySystem;
    }

    public String getHistoryId() {
        return historyId;
    }

    public void setHistoryId(String historyId) {
        this.historyId = historyId;
    }

    public String getSourceName() {
        return sourceName;
    }

    public void setSourceName(String sourceName) {
        this.sourceName = sourceName;
    }

    private List<OrderDetailVO> children; //子集数据

    public List<OrderDetailVO> getChildren() {
        return children;
    }

    public void setChildren(List<OrderDetailVO> children) {
        this.children = children;
    }

    public Long getTid() {
        return tid;
    }

    public void setTid(Long tid) {
        this.tid = tid;
    }

    public BigDecimal getUnDeliverNumsSum() {
        return unDeliverNumsSum;
    }

    public void setUnDeliverNumsSum(BigDecimal unDeliverNumsSum) {
        this.unDeliverNumsSum = unDeliverNumsSum;
    }

    /**
     * 序号
     */
    public java.lang.String getDetailIndex() {
        return detailIndex;
    }

    /**
     * 序号
     */
    public void setDetailIndex(java.lang.String detailIndex) {
        this.detailIndex = detailIndex;
    }
    /**
     * parent_id
     */
    public java.lang.Long getParentId() {
        return parentId;
    }

    /**
     * parent_id
     */
    public void setParentId(java.lang.Long parentId) {
        this.parentId = parentId;
    }
    /**
     * 是否末级
     */
    public Boolean getLeafFlag() {
        return leafFlag;
    }

    public void setLeafFlag(Boolean leafFlag) {
        this.leafFlag = leafFlag;
    }

    /**
     * 订单主键ID
     */
    public java.lang.Long getOrderId() {
        return orderId;
    }

    /**
     * 订单主键ID
     */
    public void setOrderId(java.lang.Long orderId) {
        this.orderId = orderId;
    }
    /**
     * 计划主键ID
     */
    public java.lang.Long getPlanId() {
        return planId;
    }

    /**
     * 计划主键ID
     */
    public void setPlanId(java.lang.Long planId) {
        this.planId = planId;
    }
    /**
     * 计划明细主键ID
     */
    public java.lang.Long getPlanDetailId() {
        return planDetailId;
    }

    /**
     * 计划明细主键ID
     */
    public void setPlanDetailId(java.lang.Long planDetailId) {
        this.planDetailId = planDetailId;
    }
    /**
     * 使用计划名称
     */
    public java.lang.String getPlanName() {
        return planName;
    }

    /**
     * 使用计划名称
     */
    public void setPlanName(java.lang.String planName) {
        this.planName = planName;
    }
    /**
     * 计划编码
     */
    public java.lang.String getPlanBillCode() {
        return planBillCode;
    }

    /**
     * 计划编码
     */
    public void setPlanBillCode(java.lang.String planBillCode) {
        this.planBillCode = planBillCode;
    }
    /**
     * 计划编制人
     */
    public java.lang.String getPlanEmployeeName() {
        return planEmployeeName;
    }

    /**
     * 计划编制人
     */
    public void setPlanEmployeeName(java.lang.String planEmployeeName) {
        this.planEmployeeName = planEmployeeName;
    }
    /**
     * 施工部位
     */
    public java.lang.String getConstruction() {
        return construction;
    }

    /**
     * 施工部位
     */
    public void setConstruction(java.lang.String construction) {
        this.construction = construction;
    }
    /**
     * 物资主键
     */
    public java.lang.Long getMaterialId() {
        return materialId;
    }

    /**
     * 物资主键
     */
    public void setMaterialId(java.lang.Long materialId) {
        this.materialId = materialId;
    }
    /**
     * 物资名称
     */
    public java.lang.String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(java.lang.String materialName) {
        this.materialName = materialName;
    }
    /**
     * 物资类别
     */
    public java.lang.Long getMaterialTypeId() {
        return materialTypeId;
    }

    /**
     * 物资类别
     */
    public void setMaterialTypeId(java.lang.Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    /**
     * 物资类别名称
     */
    public java.lang.String getMaterialTypeName() {
        return materialTypeName;
    }

    /**
     * 物资类别名称
     */
    public void setMaterialTypeName(java.lang.String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    /**
     * 物料编码
     */
    public java.lang.String getMaterialCode() {
        return materialCode;
    }

    /**
     * 物料编码
     */
    public void setMaterialCode(java.lang.String materialCode) {
        this.materialCode = materialCode;
    }
    /**
     * 单位
     */
    public java.lang.String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(java.lang.String unit) {
        this.unit = unit;
    }
    /**
     * 规格型号
     */
    public java.lang.String getSpec() {
        return spec;
    }

    /**
     * 规格型号
     */
    public void setSpec(java.lang.String spec) {
        this.spec = spec;
    }
    /**
     * 计划数量
     */
    public java.math.BigDecimal getPlanNumsSum() {
        return planNumsSum;
    }

    /**
     * 计划数量
     */
    public void setPlanNumsSum(java.math.BigDecimal planNumsSum) {
        this.planNumsSum = planNumsSum;
    }
    /**
     * 接收数量
     */
    public java.math.BigDecimal getReceiveNumsSum() {
        return receiveNumsSum;
    }

    /**
     * 接收数量
     */
    public void setReceiveNumsSum(java.math.BigDecimal receiveNumsSum) {
        this.receiveNumsSum = receiveNumsSum;
    }
    /**
     * 计划剩余数量
     */
    public java.math.BigDecimal getSurplusNumsSum() {
        return surplusNumsSum;
    }

    /**
     * 计划剩余数量
     */
    public void setSurplusNumsSum(java.math.BigDecimal surplusNumsSum) {
        this.surplusNumsSum = surplusNumsSum;
    }
    /**
     * 订单数量
     */
    public java.math.BigDecimal getOrderNumsSum() {
        return orderNumsSum;
    }

    /**
     * 订单数量
     */
    public void setOrderNumsSum(java.math.BigDecimal orderNumsSum) {
        this.orderNumsSum = orderNumsSum;
    }
    /**
     * 发货数量
     */
    public java.math.BigDecimal getDeliverNumsSum() {
        return deliverNumsSum;
    }

    /**
     * 发货数量
     */
    public void setDeliverNumsSum(java.math.BigDecimal deliverNumsSum) {
        this.deliverNumsSum = deliverNumsSum;
    }
    /**
     * 验收数量
     */
    public java.math.BigDecimal getCheckNumsSum() {
        return checkNumsSum;
    }

    /**
     * 验收数量
     */
    public void setCheckNumsSum(java.math.BigDecimal checkNumsSum) {
        this.checkNumsSum = checkNumsSum;
    }
    /**
     * 生产厂家
     */
    public java.lang.String getMaterialManufacturer() {
        return materialManufacturer;
    }

    /**
     * 生产厂家
     */
    public void setMaterialManufacturer(java.lang.String materialManufacturer) {
        this.materialManufacturer = materialManufacturer;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    
}
